download <- function(study_id, path) {
  suppressMessages(library(dplyr))
  logs_mapping <- data.frame(matrix(ncol = 5))
  colnames(logs_mapping) <- c("studyId", "analysisId", "Total_Metabolites", "Mapped_Metabolites", "Unmapped_Percent")
  logs_write_gct <- data.frame(matrix(ncol = 6))
  colnames(logs_write_gct) <- c("studyId", "analysisId", "Total_Metabolites", "Mapped_Metabolites", "Unmapped_Percent", "Unmapped_Metabolites")
  logs_error <- data.frame(matrix(ncol = 3))
  colnames(logs_error) <- c("studyId", "analysisId", "error") # Why do we even have the column 'analysisId' when we are not even adding anything to it?
  combined_data <- read.csv(paste(path,'mework_refmet_data/combined_database_mework_refmet.csv', sep=""), stringsAsFactors = FALSE, check.names=FALSE)
  # Rename the column 'name' to 'Metabolite'
  colnames(combined_data)[which(colnames(combined_data)=="name")] <- "Metabolite"

  study <- study_id
  filenames <- list()

  all_analysis <- tryCatch({ # What does adding the term '[["analysis_id"]]' at the end mean? Does it mean that we are picking out the column 'analysis_id'?
        # Is this column created by default by
        all_analysis <- as.vector(unique(data.table::rbindlist(jsonlite::fromJSON(paste("https://www.metabolomicsworkbench.org/rest/study/study_id/", study,"/data", sep = ""), flatten=TRUE),fill=TRUE)[["analysis_id"]]))
        all_analysis
    },error=function(e) {
        all_analysis <- "Connection Error"
        print(e)
        return(all_analysis)
    }
    )
    if(identical(class(all_analysis), "character") && all_analysis=="Connection Error"){
        print(paste('error fetching all_analysis data for study ',study, sep = ""))
        logs_error_1 <- data.frame(matrix(ncol = 3))
        colnames(logs_error_1) <- c("studyId", "analysisId", "error")
        logs_error_1$studyId <- study
        logs_error_1$error <- paste('error fetching all_analysis data for study ',study, sep = "")
        logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
        next
    }
    for (analysis in all_analysis) {
        print(paste('Creating gct for study ',study, " and analysis ", analysis, sep = ""))
        study_url <- paste("https://www.metabolomicsworkbench.org/rest/study/analysis_id/",analysis,"/mwtab", sep = "")
        study_data <- tryCatch({
            study_data <- jsonlite::fromJSON(study_url, flatten=TRUE)
            study_data
        },error=function(e) {
            study_data <- "Connection Error"
            print(e)
            return(study_data)
        }
        )
        if(identical(class(study_data), "character") && study_data=="Connection Error"){
            print(paste('error fetching study data for study ',study, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            # Should we not be adding the 'analysisId' which lead to a 'Connection Error'?
            logs_error_1$error <- paste('error fetching study data for study ',study, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        data1 <- data.frame(matrix(ncol = 6))
        colnames(data1) <- c("studyId", "analysisId", "Total_Metabolites", "Mapped_Metabolites", "Percent")
        matrix <- tryCatch({
            # Only one of 'MS_METABOLITE_DATA' or 'NMR_METABOLITE_DATA' or none are present
            if(!identical(study_data$MS_METABOLITE_DATA$Data, NULL)){
                if(identical(class(study_data$MS_METABOLITE_DATA$Data), "list")){
                    # If a list
                    for (i in 1:length(study_data$MS_METABOLITE_DATA$Data)) {
                        if(!identical(class(study_data$MS_METABOLITE_DATA$Data[i][[1]]),"list")) {
                            # If not a list
                            study_data$MS_METABOLITE_DATA$Data[i] <- NULL
                        }
                    }
                    matrix <- as.data.frame(data.table::rbindlist(study_data$MS_METABOLITE_DATA$Data, fill = TRUE))
                }
                else{
                    matrix <- as.data.frame(study_data$MS_METABOLITE_DATA$Data) # Then it's just one element, not a list. Add it.
                }
            }else if(!identical(study_data$NMR_METABOLITE_DATA$Data, NULL)){
                if(identical(class(study_data$NMR_METABOLITE_DATA$Data), "list")){
                    for (i in 1:length(study_data$NMR_METABOLITE_DATA$Data)) {
                        if(!identical(class(study_data$NMR_METABOLITE_DATA$Data[i][[1]]),"list")) {
                            study_data$NMR_METABOLITE_DATA$Data[i] <- NULL
                        }
                    }
                    matrix <- as.data.frame(data.table::rbindlist(study_data$NMR_METABOLITE_DATA$Data, fill = TRUE))
                }
                else{
                    matrix <- as.data.frame(study_data$NMR_METABOLITE_DATA$Data) # Then it's just one element, not a list. Add it.
                }
            }
            # If any column name contains the words 'metabolite' or 'name', then keep the columns (?)
            if(any(stringr::str_detect(tolower(colnames(matrix)), "metabolite")) || any(stringr::str_detect(tolower(colnames(matrix)), "name"))){
                # Only keep columns that are NOT in the empty list (why?)
                matrix <- matrix[,!colnames(matrix) %in% c(""), drop = FALSE]
            }    
            else{ # If none contain those keywords, then find the column names that are "" and replace them with 'Metabolite'
                colnames(matrix)[which(colnames(matrix)=="")] <- 'Metabolite'
            }
            matrix
        },error=function(e) {
            matrix <- "Connection Error"
            print(e)
            return(matrix)
        }
        )
        if(identical(class(matrix), "character") && matrix=="Connection Error"){
            print(paste('error fetching matrix data for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error fetching matrix data for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        cdesc <- tryCatch({
            cdesc <- as.data.frame(study_data$SUBJECT_SAMPLE_FACTORS)
            cdesc
        },error=function(e) {
            cdesc <- "Connection Error"
            print(e)
            return(cdesc)
        }
        )
        if(identical(class(cdesc), "character") && cdesc=="Connection Error"){
            print(paste('error fetching cdesc data for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error fetching cdesc data for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        metabolite_url <- paste("https://www.metabolomicsworkbench.org/rest/study/analysis_id/",analysis,"/metabolites", sep = "")
        rdesc <- tryCatch({
            if(sum(stringr::str_detect(as.data.frame(jsonlite::fromJSON(metabolite_url, flatten=TRUE), stringsAsFactors = FALSE)[1,], analysis))>1){
                metabolite_data <- data.table::rbindlist(jsonlite::fromJSON(metabolite_url, flatten=TRUE), fill = TRUE)
            }else{
                metabolite_data <- jsonlite::fromJSON(metabolite_url, flatten=TRUE)
            }
            metabolite_data <- as.data.frame(apply(metabolite_data,2,function(x)gsub('([\n\t])', '',x)))
            metabolite_data <- as.data.frame(apply(metabolite_data,2,function(x)gsub('c(\\$)', '',x)))
            metabolite_data1 <- metabolite_data[,-c(1:3), drop = FALSE]   
            colnames(metabolite_data1)[which(colnames(metabolite_data1)=="refmet_name")] <- 'name'
            colnames(metabolite_data1)[which(colnames(metabolite_data1)=="metabolite_name")] <- 'Metabolite'
            if(identical(study_data$MS_METABOLITE_DATA$Metabolites, NULL) && identical(study_data$NMR_METABOLITE_DATA$Metabolites, NULL)){
                rdesc <- metabolite_data1
            }else if(!identical(study_data$MS_METABOLITE_DATA$Metabolites, NULL)){
                if(identical(class(study_data$MS_METABOLITE_DATA$Metabolites), "data.frame")){
                    rdesc1 <- as.data.frame(study_data$MS_METABOLITE_DATA$Metabolites)
                }else if(identical(class(study_data$MS_METABOLITE_DATA$Metabolites), "list")){
                    for (i in 1:length(study_data$MS_METABOLITE_DATA$Metabolites)) if(!identical(class(study_data$MS_METABOLITE_DATA$Metabolites[i][[1]]),"list")) study_data$MS_METABOLITE_DATA$Metabolites[i] <- NULL
                    rdesc1 <- data.table::rbindlist(study_data$MS_METABOLITE_DATA$Metabolites, fill = TRUE)
                }
                colnames(rdesc1)[which(colnames(rdesc1)=="metabolite_name")] <- 'Metabolite'
                rdesc <- as.data.frame(merge(rdesc1, metabolite_data1, by = intersect(colnames(rdesc1), colnames(metabolite_data1)), all.x = TRUE))
            }else if(!identical(study_data$NMR_METABOLITE_DATA$Metabolites, NULL)){
                if(identical(class(study_data$NMR_METABOLITE_DATA$Metabolites), "data.frame")){
                    rdesc1 <- as.data.frame(study_data$NMR_METABOLITE_DATA$Metabolites)
                }else if(identical(class(study_data$NMR_METABOLITE_DATA$Metabolites), "list")){
                    for (i in 1:length(study_data$NMR_METABOLITE_DATA$Metabolites)) if(!identical(class(study_data$NMR_METABOLITE_DATA$Metabolites[i][[1]]),"list")) study_data$NMR_METABOLITE_DATA$Metabolites[i] <- NULL
                    rdesc1 <- data.table::rbindlist(study_data$NMR_METABOLITE_DATA$Metabolites, fill = TRUE)
                }
                colnames(rdesc1)[which(colnames(rdesc1)=="metabolite_name")] <- 'Metabolite'
                rdesc <- as.data.frame(merge(rdesc1, metabolite_data1, by = intersect(colnames(rdesc1), colnames(metabolite_data1)), all.x = TRUE))
            }
            if(any(stringr::str_detect(tolower(colnames(rdesc)), "pubchem"))){
                colnames(rdesc)[which(stringr::str_detect(tolower(colnames(rdesc)), "pubchem"))] <- "pubchem_cid"
            }
            if(any(stringr::str_detect(tolower(colnames(rdesc)), "kegg"))){
                colnames(rdesc)[which(stringr::str_detect(tolower(colnames(rdesc)), "kegg"))] <- "kegg_id"
            }
            rdesc <- rdesc[,!duplicated(colnames(rdesc), fromLast = TRUE), drop = FALSE]
            rdesc
        },error=function(e) {
            rdesc <- "Connection Error"
            print(e)
            return(rdesc)
        }
        )
        if(identical(class(rdesc), "character") && rdesc=="Connection Error"){
            print(paste('error fetching rdesc data for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error fetching rdesc data for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        rdesc_combined <- tryCatch({
                # if the new set created from intersections is empty (if the comparison to the empty 'character(0)' is true)
                # That menas, nothing was in common
            if(!identical(intersect(colnames(rdesc), colnames(combined_data)), character(0))){
                # If 'pubchem_cid' is in the column names of 'rdesc'
                if(c("pubchem_cid") %in% colnames(rdesc)){
                    # Join the rows on the basis of the column 'pubchem_cid' which is common between 'rdesc' and 'combined_data'
                    rdesc2 <- as.data.frame(merge(rdesc[!is.na(rdesc$pubchem_cid),, drop = FALSE], combined_data[,c("pubchem_cid", setdiff(colnames(combined_data), colnames(rdesc))), drop = FALSE], by = "pubchem_cid", all.x = TRUE))
                    rdesc_combined <- suppressMessages(dplyr::bind_rows(rdesc2, dplyr::anti_join(rdesc, rdesc2)))
                }else if(c("kegg_id") %in% colnames(rdesc) && !c("pubchem_cid") %in% colnames(rdesc)){
                    # If 'kegg_id' is in the column names and 'pubchem_cid' is NOT in the column names (why is that last statement nescessary?
                    # It would have to be False anyways for the control to shift to this statement)
                    # Merge those entries in 'rdesc' whose entries in column 'kegg_id' are NOT NaN with all entries of 'combined_data' that exist in columns that are in 'combined_data' 
                    # but not in 'rdesc'.
                    # Join the rows on the basis of the column 'kegg_id' which is common between 'rdesc' and 'combined_data'
                    rdesc2 <- as.data.frame(merge(rdesc[!is.na(rdesc$kegg_id),, drop = FALSE], combined_data[,c("kegg_id", setdiff(colnames(combined_data), colnames(rdesc))), drop = FALSE], by = "kegg_id", all.x = TRUE))
                    # Anti-join (http://zevross.com/blog/2014/08/05/using-the-r-function-anti_join-to-find-unmatched-records/) finds the elements that are in
                    # 'rdesc' but not in 'rdesc2'
                    # We then row-bind these rows (that were not in 'rdesc2') to the entries of 'rdesc2'
                    rdesc_combined <- suppressMessages(dplyr::bind_rows(rdesc2, dplyr::anti_join(rdesc, rdesc2)))
                }
                else{
                    # Join the rows on the basis of the column 'Metabolite' which is common between 'rdesc' and 'combined_data'
                    rdesc_combined <- as.data.frame(merge(rdesc, combined_data[,c("Metabolite", setdiff(colnames(combined_data), colnames(rdesc))), drop = FALSE], by = "Metabolite", all.x = TRUE))
                }
            }
            else{
                rdesc_combined <- rdesc
            }
            logs_mapping_1 <- data.frame(matrix(ncol = 5))
            colnames(logs_mapping_1) <- c("studyId", "analysisId", "Total_Metabolites", "Mapped_Metabolites", "Unmapped_Percent")
            logs_mapping_1$studyId <- study
            logs_mapping_1$analysisId <- analysis
            logs_mapping_1$Total_Metabolites <- nrow(rdesc)
            logs_mapping_1$Mapped_Metabolites <- nrow(rdesc_combined)
            logs_mapping_1$Unmapped_Percent <- 100*((nrow(rdesc_combined)- nrow(rdesc))/nrow(rdesc))
            logs_mapping <- dplyr::bind_rows(logs_mapping, logs_mapping_1)
            rdesc_combined
        },error=function(e) {
            rdesc_combined <- "Connection Error"
            print(e)
            return(rdesc_combined)
        }
        )
        if(identical(class(rdesc_combined), "character") && rdesc_combined=="Connection Error"){
            print(paste('error merging rdesc with metabolite database for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        matrix1 <- tryCatch({
            matrix1 <- matrix
            # if the word 'metabolite' is present somewhere in the column name string, replace it with 'Metabolite'. Hopefully,
            # we get only one unique output
            colnames(matrix1)[which(stringr::str_detect(tolower(colnames(matrix1)), "metabolite"))] <- "Metabolite"
            matrix1$Metabolite <- stringr::str_replace_all(string = matrix1$Metabolite, pattern = c("_"), replacement = ",")
            # If duplicates happen to arise in the 'Metabolite', then add numbers to the end to seperate them out
            matrix1$rowname_id <- make.unique(matrix1$Metabolite)
            # Why are we doing this?
            write.csv(as.data.frame(matrix1), "matrix1.csv", row.names = FALSE)
            matrix1 <- as.data.frame(read.csv("matrix1.csv", check.names=FALSE, stringsAsFactors = FALSE))
            # Only pick those columns which are not filled with NA
            matrix1 <- matrix1[, colSums(is.na(matrix1)) != nrow(matrix1), drop = FALSE]
            if (file.exists("matrix1.csv")) file.remove("matrix1.csv")
            matrix1
        },error=function(e) {
            matrix1 <- "Connection Error"
            print(e)
            return(matrix1)
        }
        )
        if(identical(class(matrix1), "character") && matrix1=="Connection Error"){
            print(paste('error in performing operations on matrix for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error in performing operations on matrix for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        cdesc1 <- tryCatch({
            cdesc1 <- cdesc
            cdesc1 <- cdesc1[!duplicated(cdesc1$`Sample ID`),,drop = FALSE]
            rownames(cdesc1) <- cdesc1$`Sample ID`
            colnames(cdesc1)[which(colnames(cdesc1)=="Sample ID")] <- 'Sample'
            cdesc1 <- cdesc1 %>% dplyr::select(c("Sample"), everything())
            cdesc1
        },error=function(e) {
            cdesc1 <- "Connection Error"
            print(e)
            return(cdesc1)
        }
        )
        if(identical(class(cdesc1), "character") && cdesc1=="Connection Error"){
            print(paste('error in performing operations on cdesc for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error in performing operations on cdesc for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        rdesc_combined1 <- tryCatch({
            rdesc_combined1 <- rdesc_combined
            rdesc_combined1$Metabolite <- stringr::str_replace_all(string = rdesc_combined1$Metabolite, pattern = c("_"), replacement = ",")
            # Why are we doing this?
            write.csv(as.data.frame(rdesc_combined1), "rdesc_combined1.csv", row.names = FALSE)
            rdesc_combined1 <- as.data.frame(read.csv("rdesc_combined1.csv", check.names=FALSE, stringsAsFactors = FALSE))
            if (file.exists("rdesc_combined1.csv")) file.remove("rdesc_combined1.csv")
            logs_write_gct1 <- data.frame(matrix(ncol = 6))
            colnames(logs_write_gct1) <- c("studyId", "analysisId", "Total_Metabolites", "Mapped_Metabolites", "Unmapped_Percent", "Unmapped_Metabolites")
            # Take all the values unique to the dataframe 'Matrix1''s column 'Metabolite' and not in the dataframe 'rdesc_combined1''s column 'Metabolite'.
            # List them out seperated by ' || '
            logs_write_gct1$Unmapped_Metabolites <- paste(setdiff(matrix1$Metabolite, rdesc_combined1$Metabolite), collapse = " || ")
            logs_write_gct1$studyId <- study
            logs_write_gct1$analysisId <- analysis
            logs_write_gct1$Total_Metabolites <- nrow(matrix1)
            common_metab <- intersect(matrix1$Metabolite, rdesc_combined1$Metabolite) # So this should not contain any Metabolite labels that have 
            # numbers appended to the end
            common_metab <- sort(common_metab) # Sort by name, which then, will be used to rank them also.
            # Get all the rows in 'matrix1' whose entries in 'Metabolite' are in the set 'common_metab'
            matrix1 <- dplyr::filter(matrix1, Metabolite %in% common_metab)
            logs_write_gct1$Mapped_Metabolites <- nrow(matrix1)
            # Why am I looking into index 2 of 'Total_Metabolites' when only a single entry was entered into it?
            logs_write_gct1$Unmapped_Percent <- 100*((logs_write_gct1$Total_Metabolites[2] - logs_write_gct1$Mapped_Metabolites[2])/logs_write_gct1$Total_Metabolites[2])
            logs_write_gct <- dplyr::bind_rows(logs_write_gct, logs_write_gct1)
            # So, the metabolites that were not in the interesection of tables 'matrix1' and 'rdesc_combined1' are treated the same way as far as 'factoring' goes, right?
            rdesc_combined1 <- rdesc_combined1 %>% dplyr::arrange(factor(Metabolite, levels = common_metab))
            # The 'match' function will give us the index locations of the 1st match of the individual patterns in 'vec1' in 'vec2'. But how to deal with the matches
            # that failed (especially incase of the metabolite labels that have a number appended to them)?
            rdesc_combined1 <- rdesc_combined1[match(matrix1$Metabolite, rdesc_combined1$Metabolite),, drop = FALSE]
            rdesc_combined1$rowname_id <- make.unique(rdesc_combined1$Metabolite)
            rownames(rdesc_combined1) <- rdesc_combined1$rowname_id
            colnames(rdesc_combined1)[which(colnames(rdesc_combined1)=="Metabolite")] <- 'compound'
            colnames(rdesc_combined1)[which(colnames(rdesc_combined1)=="kegg_id")] <- 'compoundId'
            rdesc_combined1$compound <- matrix1$rowname_id
            rdesc_combined1 <- rdesc_combined1[colSums(!is.na(rdesc_combined1)) > 0]
            rdesc_combined1
        },error=function(e) {
            rdesc_combined1 <- "Connection Error"
            print(e)
            return(rdesc_combined1)
        }
        )
        if(identical(class(rdesc_combined1), "character") && rdesc_combined1=="Connection Error"){
            print(paste('error in performing operations on rdesc for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error in performing operations on rdesc for study ',study," and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }
        x <- tryCatch({
            if(!dir.exists("GCTs")) dir.create("GCTs")
            rownames(matrix1) <- matrix1$rowname_id
            # Take all columns except column 'Metabolite' and 'rowname_id' 
            matrix1 <- matrix1[ , !(names(matrix1) %in% c("Metabolite", "rowname_id")), drop = FALSE]
            # Select only those column names of data-frame 'matrix1' that are in common with the values in column 'Sample' of data-frame 'cdesc1' (Column description?)
            matrix1 <- matrix1 %>% dplyr::select(intersect(colnames(.), cdesc1$Sample))
            if(nrow(matrix1)==1){
                # If there is only one row, make that into a data-frame
                suppressWarnings(matrix2 <- t(as.data.frame(sapply(matrix1, as.numeric))))
            }else{
                suppressWarnings(matrix2 <- sapply(matrix1, as.numeric))
            }
            rownames(matrix2) <- rownames(matrix1)
            cdesc1 <- cdesc1[match(colnames(matrix1), cdesc1$Sample),,drop = FALSE]
            if(length(common_metab)>0){
                gct <- mapGCT::to_GCT(mat = as.matrix(matrix2), cdesc = cdesc1, rdesc = rdesc_combined1[,!colnames(rdesc_combined1) %in% c("rowname_id"), drop = FALSE])
            }
            else{
                gct <- mapGCT::to_GCT(mat = as.matrix(matrix2), cdesc = cdesc1)
            }
            mapGCT::write_gct(gct,paste("GCTs/",study,"_", analysis, ".gct", sep = ""))
            x <- paste("GCTs/",study,"_", analysis, ".gct", sep = "")
            filenames <- append(filenames, x)
        },error=function(e) {
            x <- "Connection Error"
            print(e)
            return(x)
        }
        )
        if(identical(class(x), "character") && x=="Connection Error"){
            print(paste('error writing gct for study ',study," and analysis ", analysis, sep = ""))
            logs_error_1 <- data.frame(matrix(ncol = 3))
            colnames(logs_error_1) <- c("studyId", "analysisId", "error")
            logs_error_1$studyId <- study
            logs_error_1$analysisId <- analysis
            logs_error_1$error <- paste('error writing gct for study ',study,"and analysis ", analysis, sep = "")
            logs_error <- dplyr::bind_rows(logs_error, logs_error_1)
            next
        }else{
            gct_name <- paste(study,"_", analysis, ".gct", sep = "")
        
        }
        
    }
    return (c(gct_paths=filenames))

}
